
from distutils.core import setup

setup(
    name = 'a569',
    version = '1.3.0',
    py_modules = ['a569'],
    author = 'hfpython',
    author_email = 'notachance@abc.com',
    description = 'A simple primer of nested lists'
)
    
